package com.ruoyi.web.work.controller;

import java.util.Arrays;
import java.util.List;

import com.ruoyi.common.annotation.Anonymous;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.web.work.domain.WardInfo;
import com.ruoyi.web.work.service.IWardInfoService;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 病区信息
 * @author zeng
 * @date 2024-07-18
 */

@RestController
@RequestMapping("/work/ward")
public class WardInfoController extends BaseController {
    @Autowired
    private IWardInfoService wardInfoService;

    @PreAuthorize("@ss.hasPermi('work:ward:list')")
    @GetMapping("/list")
    public TableDataInfo list(WardInfo wardInfo){
        startPage();
        List<WardInfo> list = wardInfoService.selectList(wardInfo);
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasPermi('work:ward:query')")
    @GetMapping(value = "/detail/{id}")
    public AjaxResult detail(@PathVariable("id") Long id){
        return AjaxResult.success(wardInfoService.getById(id));
    }

    @PreAuthorize("@ss.hasPermi('work:ward:add')")
    @Log(title = "病区信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    public AjaxResult add(@RequestBody WardInfo wardInfo){
        return toAjax(wardInfoService.save(wardInfo));
    }

    @PreAuthorize("@ss.hasPermi('work:ward:edit')")
    @Log(title = "病区信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody WardInfo wardInfo){
        return toAjax(wardInfoService.updateById(wardInfo));
    }

    @PreAuthorize("@ss.hasPermi('work:ward:remove')")
    @Log(title = "病区信息", businessType = BusinessType.DELETE)
    @GetMapping("/remove/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids){
        return toAjax(wardInfoService.removeByIds(Arrays.asList(ids)));
    }
}
